# title

## Problem

Add a short description of the problem, e.g., Level 7 printer is flashing red and won't print

## Solution

Describe how someone would solve the problem in a short, step-by-step guide:

1. Add steps that are simple and self-contained
1. Add illustrations to instructions by typing /image
1. Stick to 3-5 steps per task to avoid overloading readers

Highlight important information in a panel like this one. To edit this panel's color or style, select one of the options in the menu below.

## Related articles

The content by label feature displays related articles automatically, based on labels you choose. To edit options for this feature, select the placeholder below and tap the pencil icon.
